import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  // {
  //   component: 'Input',
  //   fieldName: 'equName',
  //   label: '设备名称'
  // },
  // {
  //   component: 'Input',
  //   fieldName: 'assetNo',
  //   label: '资产编号'
  // },
  {
    component: 'Input',
    fieldName: 'params.searchValue',
    label: '关键字'
  },
  // {
  //   component: 'Select',
  //   componentProps: {
  //     options: getDictOptions(DictEnum.EIMS_INSPECT_STATUS)
  //   },
  //   fieldName: 'status',
  //   label: '状态'
  // },
  {
    component: 'RangePicker',
    fieldName: 'planTime',
    label: '点检日期'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_INSPECT_RESULT)
    },
    fieldName: 'inspResult',
    label: '点检结果'
  }
  // {
  //   component: 'TreeSelect',
  //   // 在drawer里更新 这里不需要默认的componentProps
  //   defaultValue: undefined,
  //   fieldName: 'inspDept',
  //   label: '点检部门'
  // },
  // {
  //   component: 'Select',
  //   componentProps: {
  //     allowClear: true,
  //     showSearch: true,
  //     getPopupContainer
  //   },
  //   fieldName: 'inspUser',
  //   label: '点检人'
  // }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '点检编号',
    field: 'inspCode',
    minWidth: 200,
    fixed: 'left'
  },

  {
    title: '状态',
    field: 'status',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return renderDict(row.status, DictEnum.EIMS_INSPECT_STATUS);
      }
    }
  },
  {
    title: '设备名称',
    field: 'equName',
    minWidth: 200
  },
  {
    title: '资产编号',
    field: 'assetNo',
    minWidth: 160
  },
  {
    title: '点检项',
    field: 'inspName',
    minWidth: 160
  },
  {
    title: '点检结果',
    field: 'inspResult',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        if (!row.inspResult) return '';
        return renderDict(row.inspResult, DictEnum.EIMS_INSPECT_RESULT);
      }
    }
  },
  // {
  //   title: '点检类型',
  //   field: 'inspType',
  //   minWidth: 120,
  //   slots: {
  //     default: ({ row }) => {
  //       return renderDict(row.inspType, DictEnum.EIMS_INSPECT_TYPE);
  //     }
  //   }
  // },
  {
    title: '点检描述',
    field: 'inspDesc',
    minWidth: 200
  },
  {
    title: '点检人',
    field: 'inspUserName',
    minWidth: 100
  },
  {
    title: '计划点检时间',
    field: 'planTime',
    minWidth: 160
  },
  {
    title: '点检时间',
    field: 'inspTime',
    minWidth: 200
  },

  {
    title: '验证人',
    field: 'verifyUserName',
    minWidth: 160
  },
  {
    title: '创建时间',
    field: 'createTime',
    minWidth: 200
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'planId'
  },
  {
    component: 'Input',
    fieldName: 'equId',
    label: '设备id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },

  {
    component: 'Input',
    fieldName: 'inspCode',
    label: '点检编号'
  },
  {
    component: 'Input',
    fieldName: 'inspName',
    label: '点检项'
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.EIMS_INSPECT_TYPE),
      optionType: 'button'
    },
    fieldName: 'inspType',
    defaultValue: '1',
    label: '点检类型'
  },
  {
    component: 'Input',
    fieldName: 'inspUser',
    label: '点检人id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'inspUserName',
    label: '点检人'
  },
  {
    component: 'Input',
    fieldName: 'inspDept',
    label: '部门id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.EIMS_INSPECT_STATUS),
      optionType: 'button'
    },
    fieldName: 'status',
    defaultValue: '0',
    label: '状态'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'planTime',
    label: '计划点检日期'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'inspTime',
    label: '点检时间'
  },
  {
    component: 'Textarea',
    fieldName: 'inspDesc',
    label: '点检描述'
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.EIMS_INSPECT_RESULT),
      optionType: 'button'
    },
    fieldName: 'inspResult',
    label: '点检结果'
  },
  {
    component: 'Input',
    fieldName: 'verifyUser',
    label: '验证人id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'verifyUserName',
    label: '验证人'
  },
  {
    component: 'Textarea',
    fieldName: 'remark',
    label: '备注'
  }
];
